initial gfx906 support

This commit is contained in:
Siu Chi Chan
2018-04-18 15:27:56 -04:00
committed by Aaron En Ye Shi
orang tua ace018501d
melakukan b898049412
6 mengubah file dengan 29 tambahan dan 8 penghapusan
+1 -1
Melihat File
@@ -32,7 +32,7 @@ THE SOFTWARE.
#define HALF_SIZE 64 * sizeof(__half)
#define HALF2_SIZE 64 * sizeof(__half2)
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__
#if __HIP_ARCH_GFX803__ || __HIP_ARCH_GFX900__ || __HIP_ARCH_GFX906__
__global__ void __halfMath(hipLaunchParm lp, __half* A, __half* B, __half* C) {
int tx = threadIdx.x;